
/* Copyright (c) CNIDR (see ../COPYRIGHT) */

/*
**  <FTW.H>
**  Header values for the third parameter to the user-supplied function
**  for ftw().
**
**  $Header: /usr/users/freewais/FreeWAIS-0.1/lib/pdftw.h,v 1.1 1993/02/16 15:08:58 freewais Exp $
*/

#define FTW_F		0	/* A normal file			*/
#define FTW_D		1	/* A directory				*/
#define FTW_DNR		2	/* Something opendir(3) failed on	*/
#define FTW_NS		3	/* Something stat(2) failed on		*/


/* choose your directory access method here: 
 */


#ifdef hpux
#define _INCLUDE_POSIX_SOURCE
#define DIRSIZ_MACRO
#define USE_DIRENT
#endif

#if defined(USG) || defined(_IBMR2)
#ifndef NeXT
#ifndef _SYS_DIRENT_INCLUDED
#include <dirent.h>
#define USE_DIRENT
#endif
#endif /* ndef NeXT */
#endif

#if defined(NeXT) || defined(BSD43)
#include <sys/dir.h>	
#define dirent direct
#endif /* def NeXT */

#if defined(BSD) 
#ifndef NeXT
#define USE_SYS_NDIR  
#include <sys/ndir.h>
#define dirent direct
#endif /* ndef NeXT */
#endif

#if  defined(ultrix)
#define USE_SYS_DIR  
#include <sys/dir.h>
#endif

#ifndef MAXNAMLEN
#define MAXNAMLEN 1024
#endif
